﻿using System;
using System.Collections.Generic;
using System.DirectoryServices.ActiveDirectory;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ArmoredCar
{
    internal class DrawningObjectArmCar : IDrawningObject
    {
        private DrawningArmoredCar _armCar = null;
        public DrawningObjectArmCar(DrawningArmoredCar car)
        {
            _armCar = car;
        }
        public float Step => _armCar?.ArmoredCar?.Step ?? 0;
        public (float Left, float Right, float Top, float Bottom)
       GetCurrentPosition()
        {
            return _armCar?.GetCurrentPosition() ?? default;
        }
        public void MoveObject(Direction direction)
        {
            _armCar?.MoveTransport(direction);
        }
        public void SetObject(int x, int y, int width, int height)
        {
            _armCar.SetPosition(x, y, width, height);
        }
        void IDrawningObject.DrawningObject(Graphics g)
        {
            if (_armCar != null)
                _armCar.DrawTransport(g);
        }
        public string GetInfo() => _armCar?.GetDataForSave();
        public static IDrawningObject Create(string data) => new DrawningObjectArmCar(data.CreateDrawningArmoredCar());

        public bool Equals(IDrawningObject? other)
        {
            if (other == null)
            {
                return false;
            }
            var otherCar = other as DrawningObjectArmCar;
            if (otherCar == null)
            {
                return false;
            }
            var car = _armCar.ArmoredCar;
            var otherCarCar = otherCar._armCar.ArmoredCar;

            if (car.GetType() != otherCarCar.GetType())
                return false;

            if (car.Speed != otherCarCar.Speed)
            {
                return false;
            }
            if (car.Weight != otherCarCar.Weight)
            {
                return false;
            }
            if (car.BodyColor != otherCarCar.BodyColor)
            {
                return false;
            }
            if (car is EntityTank tank && otherCarCar is EntityTank otherTank)
            {
                if (tank.DopColor != otherTank.DopColor)
                {
                    return false;
                }
                if (tank.TowerWeapon != otherTank.TowerWeapon)
                {
                    return false;
                }
                if (tank.AMachineGun != otherTank.AMachineGun)
                {
                    return false;
                }
            }        
            return true;
        }

    }
}
